<?php
class WPPM_Ultimate_Options extends WPPM_Ultimate{
	
	/**
	 * setup some class vars - one for page hook -help guides / etc | one for option name
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 * 
	 *
	 */
	
	public $page_hook;
	public $option_name = WPPM_OPTION;
	
	
	
	/**
	 * constructor - adds all the functions to wp actions
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 * 
	 *
	 */
	function __construct(){
		
		if ( is_admin() ){
			add_action('admin_menu', array(&$this, '_add_page'));
		}//if
		
		add_action('admin_init', array(&$this, '_register_settings') );
		
		add_action( 'admin_notices', array(&$this,'_admin_notices'));
		
	}//function
	
	
	
	
	/**
	 * internal function for displaying input fileds - reduces markup
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 * removed support for wysiwyg as wp 3.3 contains wp_editor() function
	 *
	 */
	function _field($type, $options_name, $option, $id = '', $length = '', $value = '', $placeholder = ''){
		
		$options_array = get_option($options_name);
		
		switch($type){
			
			case 'checkbox':
			
				echo "<input ".checked( isset($options_array[$option]), 1 , false)." id='".$id."' name='".$options_name."[".$option."]' type='checkbox' value ='1'/>";
				
			break;
			case 'text':
			
				echo "<input id='".$id."' name='".$options_name."[".$option."]"."' size='".$length."' type='text' value='";
				echo isset($options_array[$option]) ? $options_array[$option] : '';
				echo "' placeholder='{$placeholder}'/>";

			break;
			case 'password':
			
				echo "<input id='".$id."' name='".$options_name."[".$option."]"."' size='".$length."' type='password' value='";
				echo isset($options_array[$option]) ? $options_array[$option] : '';
				echo "' />"; 
				
			break;
			case 'textarea':
			
				echo "<textarea id='".$id."' name='".$options_name."[".$option."]"."' rows='4' cols='60' type='textarea'>";
				echo isset($options_array[$option]) ? $options_array[$option] : '';
				echo "</textarea>";
				
			break;
			case 'select':
			
				echo "<select id='".$id."' name='".$options_name."[".$option."]"."'>";
				
					foreach($value as $item) {
						echo "<option value='$item' ".selected($options_array[$option], $item, false).">$item</option>";
					}//foreach
					
				echo "</select>";
				
			break;
			case 'file':
			
				echo '<input type="file" name="'.$option.'" size="'.$length.'"/>';
				
			break;
	
		}//switch
		
	}//function
	
	
	
	
	
	/**
	 * add options page to post type
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 * 
	 *
	 */
	function _add_page() {
		
		$this->page_hook = add_submenu_page('edit.php?post_type=projects','WP Project Managment Ultimate Options','Managment Options','administrator','wp_pm', array(&$this,'_page_html'));
		
		$this->page_hook2 = add_submenu_page('edit.php?post_type=projects','WP Project Managment Ultimate Support','Help / Support','administrator','wp_pm_support', array(&$this,'_support_page_html'));
		
		add_action("load-$this->page_hook", array(&$this, '_page_help'));
		add_action("load-$this->page_hook2", array(&$this, '_page_help'));
	}//function
	
	
	
	
	/**
	 * register the settings sections for use on the options page
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 *
	 */
	function _register_settings(){
		
		register_setting( $this->option_name.'_group', $this->option_name, array(&$this,'_validate_options'));
		
		
		add_settings_section($this->option_name.'_section', __('Project Notifications',WPPM_LANG), array(&$this,'project_notify_intro'), __FILE__);
		
		
			add_settings_field('project_notify_name_options', __('Notification From Name',WPPM_LANG), array(&$this,'project_notify_name_options'), __FILE__, $this->option_name.'_section');
			
			add_settings_field('project_notify_email_options', __('Notification From Email',WPPM_LANG), array(&$this,'project_notify_email_options'), __FILE__, $this->option_name.'_section');
			
			
		
		add_settings_section($this->option_name.'_section1', __('Project Details Table',WPPM_LANG), array(&$this,'project_table_intro'), __FILE__);
		
		
			add_settings_field('project_title_options', __('Project Title',WPPM_LANG), array(&$this,'project_title_options'), __FILE__, $this->option_name.'_section1');
			
			add_settings_field('project_users_options', __('Project Users',WPPM_LANG), array(&$this,'project_users_options'), __FILE__, $this->option_name.'_section1');
			
			add_settings_field('project_start_options', __('Project Start Date',WPPM_LANG), array(&$this,'project_start_options'), __FILE__, $this->option_name.'_section1');
			
			add_settings_field('project_end_options', __('Project End Date',WPPM_LANG), array(&$this,'project_end_options'), __FILE__, $this->option_name.'_section1');
			
			add_settings_field('project_completed_options', __('Project Completed',WPPM_LANG), array(&$this,'project_completed_options'), __FILE__, $this->option_name.'_section1');
			
			add_settings_field('project_paid_options', __('Project Paid',WPPM_LANG), array(&$this,'project_paid_options'), __FILE__, $this->option_name.'_section1');
			
		
		
		add_settings_section($this->option_name.'_section2', __('Project Description',WPPM_LANG), array(&$this,'project_description_intro'), __FILE__);
		
		
			add_settings_field('project_description_options', __('Project Description Header',WPPM_LANG), array(&$this,'project_description_options'), __FILE__, $this->option_name.'_section2');
			
			
			
			
		add_settings_section($this->option_name.'_section3', __('Project Attachments',WPPM_LANG), array(&$this,'project_attachments_intro'), __FILE__);
		
		
			add_settings_field('project_description_options', __('Project Attachments Header',WPPM_LANG), array(&$this,'project_attachments_options'), __FILE__, $this->option_name.'_section3');
			
			
			
			
		add_settings_section($this->option_name.'_section4', __('Project Comment Uploads',WPPM_LANG), array(&$this,'project_comments_uploads_intro'), __FILE__);
		
		
			add_settings_field('project_comment_options', __('Project Comment Uploads',WPPM_LANG), array(&$this,'project_comments_uploads_options'), __FILE__, $this->option_name.'_section4');
			
			add_settings_field('project_comment_options_2', __('Project Comment Upload Heading',WPPM_LANG), array(&$this,'project_comments_uploads_options_2'), __FILE__, $this->option_name.'_section4');
			
			add_settings_field('project_comment_options_3', __('Project Comment Upload Description',WPPM_LANG), array(&$this,'project_comments_uploads_options_3'), __FILE__, $this->option_name.'_section4');
			
	
	add_settings_section($this->option_name.'_section5', __('Custom CSS',WPPM_LANG), array(&$this,'project_css_intro'), __FILE__);
	
			add_settings_field('project_css_options', __('Project Page CSS',WPPM_LANG), array(&$this,'project_css_options'), __FILE__, $this->option_name.'_section5');
			
			
	}//function
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_notify_intro(){
		
		echo __('<p>Here you can choose to add custom "From" name and email address, this is what is displayed as the sender in the project notification emails:</p>',WPPM_LANG);
		
	}//function
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_notify_name_options(){
		
		$this->_field('text', $this->option_name, 'project_notify_name', $this->option_name, '30', '', __('Your Name',WPPM_LANG));

	}//function
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_notify_email_options(){
		
		$this->_field('text', $this->option_name, 'project_notify_email', $this->option_name, '30', '', __('projects',WPPM_LANG));
		
		echo '<span class="description">@'.parent::get_part_url().'</span>';

	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_table_intro(){
		
		echo __('<p>Use these options to change the text displayed in the Project Details Table. This table is displayed at the top of the project page and you can change the following titles:</p>',WPPM_LANG);
		
	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_title_options(){
		
		$this->_field('text', $this->option_name, 'project_table_title', $this->option_name, '30', '', __('Project:',WPPM_LANG));

	}//function
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_users_options(){
		
		$this->_field('text', $this->option_name, 'project_table_users', $this->option_name, '30', '', __('Users:',WPPM_LANG));

	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_start_options(){
		
		$this->_field('text', $this->option_name, 'project_table_start_date', $this->option_name, '30', '', __('Start Date:',WPPM_LANG));

	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_end_options(){
		
		$this->_field('text', $this->option_name, 'project_table_end_date', $this->option_name, '30', '', __('End Date:',WPPM_LANG));

	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_completed_options(){
		
		$this->_field('text', $this->option_name, 'project_table_completed', $this->option_name, '30', '', __('Completed:',WPPM_LANG));

	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_paid_options(){
		
		$this->_field('text', $this->option_name, 'project_table_paid', $this->option_name, '30', '', __('Paid:',WPPM_LANG));
		
		echo '<br/><br/>';
		
	}//function
	
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_description_intro(){
		
		echo __('<p>The project description Header is displayed above the projects content. Leave blank to display no header. Or choose to input a custom header title.</p>',WPPM_LANG);
		
	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_description_options(){
		
		$this->_field('text', $this->option_name, 'project_description_title', $this->option_name, '67', '', __('Project Details',WPPM_LANG));
		
		echo '<br/><br/>';
		
	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */	
	function project_attachments_intro(){
		
		echo __('<p>The project attachments Header is displayed above the list of the projects attachments. Leave blank to display no header. Or choose to input a custom header title.</p>',WPPM_LANG);
		
	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_attachments_options(){
		
		$this->_field('text', $this->option_name, 'project_attachments_title', $this->option_name, '67', '', __('Project Attachments',WPPM_LANG));
		
		echo '<br/><br/>';
		
	}//function
	
	
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_comments_uploads_intro(){
		
		echo __('<p>The project comments section contains an option for users to upload files and images to comments. There are options to customize what text / messages you shouw for these fields. They are as follows:</p>',WPPM_LANG);
		
	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_comments_uploads_options(){
		
		$this->_field('select', $this->option_name, 'project_comment_uploads_allowed', $this->option_name.'_project_comment_uploads_allowed', '', array("Enable", "Disable"));echo __(' Comment Uploads',WPPM_LANG);
		
		echo '<br/><br/>';
		
	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_comments_uploads_options_2(){
		
		$this->_field('text', $this->option_name, 'project_comment_uploads_title', $this->option_name, '67', '', __('File / Image Uploads',WPPM_LANG));

		echo '<br/><br/>';
		
	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_comments_uploads_options_3(){
		
		$options = get_option($this->option_name);
		
		wp_editor( $options['project_comment_uploads_desc'], 'projectcommentuploads', array('textarea_name' => $this->option_name.'[project_comment_uploads_desc]', 'textarea_rows' => 4) );
		
		echo '<br/><br/>';
		
	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_css_intro(){
		
		echo __('<p>The project page has some default styling already setup for a generic look. You can change this by adding custom CSS here to intergrate the page more into your sites styling.</p>',WPPM_LANG);
	
	}//function
	
	
	
	
	/**
	 * settings section - registered above
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function project_css_options(){
		
		$this->_field('textarea', $this->option_name, 'project_css', $this->option_name);

	}//function
	
	
	
	
	/**
	 * the page html
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function _page_html(){$options = get_option($this->option_name);?>
		<script type="text/javascript">
			jQuery(document).ready(function() {
				
				var selector = jQuery('#_WPPM_Options_project_comment_uploads_allowed');
				
				if(selector.val() == 'Disable'){
					jQuery(selector).parent().parent().next().fadeOut('slow');
					jQuery(selector).parent().parent().next().next().fadeOut('slow');	
				}
				
				jQuery(selector).change(function(){
					if(jQuery(this).val() == 'Enable'){jQuery(this).parent().parent().next().fadeIn('slow');jQuery(this).parent().parent().next().next().fadeIn('slow');}
					if(jQuery(this).val() == 'Disable'){jQuery(this).parent().parent().next().fadeOut('slow');jQuery(this).parent().parent().next().next().fadeOut('slow');}
				});
				
			});
		</script>
		
		<div class="wrap">
			<img src="<?php echo WPPM_IMG .'32/icon.png';?>" style="margin:14px 6px 0px 0px;float:left;"/>
			<h2 style="display:inline-block;"><?php echo get_admin_page_title(); ?></h2>

				<form method="post" action="options.php" enctype="multipart/form-data">
					<?php settings_fields($this->option_name.'_group');
							$options = get_option($this->option_name);
							do_settings_sections(__FILE__); ?>
					<p><br/><br/><input type="submit" name="<?php echo $this->option_name;?>[save]" value="Save Changes" class="button-primary" /></p>
				</form>
				<!-- <?php $options = get_option($this->option_name); print_r($options);?> -->
				<div class="clear"></div>
		</div>
	<?php }//function
	
	
	
	/**
	 * the support page html
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	function _support_page_html(){
		?>		
		<div class="wrap">
			<img src="<?php echo WPPM_IMG .'32/icon.png';?>" style="margin:14px 6px 0px 0px;float:left;"/>
			<h2 style="display:inline-block;"><?php echo get_admin_page_title(); ?></h2>
			
			<?php
			if(isset($_POST['support_request']) && isset($_POST['submit'])){
				$message = '';
				$message = $this->_get_all_data();
				$message .= '<br/><br/><strong>User Content:</strong><br/>'.$_POST['support_request'];
				
				add_filter('wp_mail_content_type',create_function('', 'return "text/html";'));
			
				if(wp_mail('contact@no-half-pixels.com', 'WPPM Support Request', $message)){
					echo '<div id="message" class="updated fade"><p>Message Sent.</p></div>';	
				}else{
					echo '<div id="message" class="error fade"><p>There was a problem sending the message, please try again.</p></div>';
				}
			
			}
			?>

				<form method="post" action="" enctype="multipart/form-data">
				<h3><?php _e('Support Request', WPPM_LANG);?></h3>
				<p><?php _e('The plugin does have quite a few features, and sometimes you may get a little lost. The best course of action if to:', WPPM_LANG);?></p>
				<p><strong>1.</strong> <?php _e('Check the contextual help (little help button in the top right of your screen). The plugin has help on pages where its needed, so check there and see if what you need is present.', WPPM_LANG);?></p>
				<p><strong>2.</strong> <?php _e('Check the plugins FAQ page <a href-"http://wordpress.org/extend/plugins/wp-project-managment-ultimate/faq/" target="_blank">here</a> to see if you issue has been raised before, and if there are any fixes.', WPPM_LANG);?></p>
				<p><strong>3.</strong> <?php _e('Check the <a href="http://wordpress.org/support/forum/plugins-and-hacks" target="_blank" >WordPress Forums</a>. I browse the forum frequently, so if you have a problem with the plugin, check in here to see if it has already been noted.', WPPM_LANG);?></p>
				<p><strong>4.</strong> <?php _e('If you\'ve tried all of the above and still have a problem, send me an email. I\'ll try to get back to you ASAP.', WPPM_LANG);?></p>
				<table class="form-table">
				<tr valign="top">
				<td><textarea name="support_request" cols="120" rows="8" ></textarea></td>
				</tr>
				</table>
				<p><br/><br/><input type="submit" name="submit" value="Send Request" class="button-primary" /></p>
				<?php echo $this->_get_all_data();?>
				</form>
				<!-- <?php $options = get_option($this->option_name); print_r($options);?> -->
				<div class="clear"></div>
		</div>
	<?php }//function
	
	
	
	
	
	/**
	 * gets server info for support request
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	private function _get_serverinfo() {
		global $wpdb;
		$sqlversion = $wpdb->get_var("SELECT VERSION() AS version");
		$mysqlinfo = $wpdb->get_results("SHOW VARIABLES LIKE 'sql_mode'");
		if (is_array($mysqlinfo)) $sql_mode = $mysqlinfo[0]->Value;
		if (empty($sql_mode)) $sql_mode = __('Not set');
		if(ini_get('safe_mode')) $safe_mode = __('On');
		else $safe_mode = __('Off');
		if(ini_get('allow_url_fopen')) $allow_url_fopen = __('On');
		else $allow_url_fopen = __('Off');
		if(ini_get('upload_max_filesize')) $upload_max = ini_get('upload_max_filesize');
		else $upload_max = __('N/A');
		if(ini_get('post_max_size')) $post_max = ini_get('post_max_size');
		else $post_max = __('N/A');
		if(ini_get('max_execution_time')) $max_execute = ini_get('max_execution_time');
		else $max_execute = __('N/A');
		if(ini_get('memory_limit')) $memory_limit = ini_get('memory_limit');
		else $memory_limit = __('N/A');
		if (function_exists('memory_get_usage')) $memory_usage = round(memory_get_usage() / 1024 / 1024, 2) . __(' MByte');
		else $memory_usage = __('N/A');
		if (is_callable('exif_read_data')) $exif = __('Yes'). " ( V" . substr(phpversion('exif'),0,4) . ")" ;
		else $exif = __('No');
		if (is_callable('iptcparse')) $iptc = __('Yes');
		else $iptc = __('No');
		if (is_callable('xml_parser_create')) $xml = __('Yes');
		else $xml = __('No');
		$data = '<ul>';
		$data .= '<li><strong>'.__('Operating System : ', WPPM_LANG).'</strong>'.PHP_OS.'</li>';
		$data .= '<li><strong>'.__('Server : ', WPPM_LANG).'</strong>'.$_SERVER["SERVER_SOFTWARE"].'</li>';
		$data .= '<li><strong>'.__('Memory usage : ', WPPM_LANG).'</strong>'.$memory_usage.'</li>';
		$data .= '<li><strong>'.__('MYSQL Version : ', WPPM_LANG).'</strong>'.$sqlversion.'</li>';
		$data .= '<li><strong>'.__('SQL Mode : ', WPPM_LANG).'</strong>'.$sql_mode.'</li>';
		$data .= '<li><strong>'.__('PHP Version : ', WPPM_LANG).'</strong>'.PHP_VERSION.'</li>';
		$data .= '<li><strong>'.__('PHP Safe Mode : ', WPPM_LANG).'</strong>'.$safe_mode.'</li>';
		$data .= '<li><strong>'.__('PHP Allow URL fopen : ', WPPM_LANG).'</strong>'.$allow_url_fopen.'</li>';
		$data .= '<li><strong>'.__('PHP Memory Limit : ', WPPM_LANG).'</strong>'.$memory_limit.'</li>';
		$data .= '<li><strong>'.__('PHP Max Upload Size : ', WPPM_LANG).'</strong>'.$upload_max.'</li>';
		$data .= '<li><strong>'.__('PHP Max Post Size : ', WPPM_LANG).'</strong>'.$post_max.'</li>';
		$data .= '<li><strong>'.__('PHP Max Script Execute Time : ', WPPM_LANG).'</strong>'.$max_execute.'s</li>';
		$data .= '<li><strong>'.__('PHP Exif support : ', WPPM_LANG).'</strong>'.$exif.'</li>';
		$data .= '<li><strong>'.__('PHP IPTC support : ', WPPM_LANG).'</strong>'.$iptc.'</li>';
		$data .= '<li><strong>'.__('PHP XML support : ', WPPM_LANG).'</strong>'.$xml.'</li>';
		$data .= '</ul>';
		return $data;
	}//function


	/**
	 * gets plugin info for support request
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	private function _get_plugins(){
		$plugins = get_plugins();
				$data = '<ul>';
					foreach($plugins as $plugin){
						$data .= '<li><strong>'.$plugin['Name'].'</strong> - '.$plugin['Version'].'</li>';
					}
				$data .= '</ul>';
				return $data;
	}//function
	
	
	
	/**
	 * gets plugin info for support request
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 */
	private function _get_all_data(){
	
			$data = '<table class="form-table">';
			$data .= '<tr valign="top">';
			$data .= '<td>';
			$data .= __('Data being sent with this request:', WPPM_LANG);
			$data .= __('<h3>Site Info</h3>', WPPM_LANG);
			$data .= '<ul>';
			$data .= '<li><strong>'.__('Admin Email', WPPM_LANG).'</strong> '.get_bloginfo('admin_email').'</li>';
			$data .= '<li><strong>'.__('Site Address', WPPM_LANG).'</strong> '.site_url().'</li>';
			$data .= '</ul>';
			$data .= '<br/><br/>';
			$data .= '<h3>'.__('Server Info', WPPM_LANG).'</h3>';
			$data .= $this->_get_serverinfo();
			$data .= '<br/><br/>';
			$data .= '<h3>'.__('Active Plugins', WPPM_LANG).'</h3>';
			$data .= $this->_get_plugins();
			$data .= '</td>';
			$data .= '</tr>';
			$data .= '</table>';
			return $data;

	}//function
	
	
	
	
	
	
	/**
	 * contextual help content
	 *
	 * @package WPPM
	 * @since 3.3
	 * needs a new hook
	 *
	 */
	function _page_help(){
		
		$screen = get_current_screen();
		if ($screen->id == $this->page_hook){
		
			
			
		$screen->add_help_tab( array(
			'id'      => 'wppm-options-1',
			'title'   => __('Project Notifications', WPPM_LANG),
			'content' => __("<br />The Project Notifications settings allow you to choose what your project users get sent in there emails. By default WordPress will send the email the email from <strong>".get_bloginfo('name')."</strong> and the email address: <strong>wordpress@".WPPM_Ultimate::get_part_url()."</strong>. Sometimes this isnt desired, so you can change that here.", WPPM_LANG),
		));
		
		$screen->add_help_tab( array(
			'id'      => 'wppm-options-2',
			'title'   => __('Project Template Labels', WPPM_LANG),
			'content' => __("<br />The Project Details Table | Project Description | Project Attachments input fields allow you to change what is displayed on the project page (when using the default page template provided with the theme). Everyone uses different words for different things, so we have provided you with the option to change what the table displays the data as.", WPPM_LANG),
		));
		
		$screen->add_help_tab( array(
			'id'      => 'wppm-options-3',
			'title'   => __('Comment Uploads', WPPM_LANG),
			'content' => __("<br />Alot of people using project managment system need the ability to share / view files as part of the project. This option isnt for everyone, but if you need it when enabled will allow you and the other users to upload files right into the comments sections of the project. These can then be viewed by any member of the project.", WPPM_LANG),
		));
		
		$screen->add_help_tab( array(
			'id'      => 'wppm-options-4',
			'title'   => __('Custom CSS', WPPM_LANG),
			'content' => __("<br />If you are happy with using the included project page template, but you would like to make a few changes, colors perhaps? You can use this box which will be added to the head of the page. The content will be added between style tags and you can use the targeted selectors from the project page template.", WPPM_LANG),
		));
		
		$screen->set_help_sidebar(__('<br/><strong>Want to show your appreciation for the plugin?</strong><br /><form style="text-align:center;margin-top:20px;" action="https://www.paypal.com/cgi-bin/webscr" method="post"><input type="hidden" name="cmd" value="_s-xclick"><input type="hidden" name="hosted_button_id" value="P7CYJYR7623K6"><input type="image" src="https://www.paypalobjects.com/en_GB/i/btn/btn_donate_SM.gif" border="0" name="submit" alt="PayPal — The safer, easier way to pay online."><img alt="" border="0" src="https://www.paypalobjects.com/en_GB/i/scr/pixel.gif" width="1" height="1"></form>', WPPM_LANG));


		}elseif( $screen->id == $this->page_hook2){
			
				$screen->add_help_tab( array(
			'id'      => 'wppm-support-1',
			'title'   => __('Support', WPPM_LANG),
			'content' => __("<br />If you are happy using the plugin, you can still use this form to send feature requests. A donation would also help improve the plugins features.", WPPM_LANG),
		));
			
				$screen->set_help_sidebar(__('<br/><strong>Want to show your appreciation for the plugin?</strong><br /><form style="text-align:center;margin-top:20px;" action="https://www.paypal.com/cgi-bin/webscr" method="post"><input type="hidden" name="cmd" value="_s-xclick"><input type="hidden" name="hosted_button_id" value="P7CYJYR7623K6"><input type="image" src="https://www.paypalobjects.com/en_GB/i/btn/btn_donate_SM.gif" border="0" name="submit" alt="PayPal — The safer, easier way to pay online."><img alt="" border="0" src="https://www.paypalobjects.com/en_GB/i/scr/pixel.gif" width="1" height="1"></form>', WPPM_LANG));

		}else{
			return;
		}
	
	}//function
	
	
	
	
	/**
	 * vaildate options callback
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 * adds settings updated error to page as well
	 *
	 */
	function _validate_options($plugin_options){
		//validate the file upload
		$keys = array_keys($_FILES);$i = 0;
		foreach ( $_FILES as $image ) {// if a files was upload
		if ($image['size']) {// if it is an image
		if ( preg_match('/(jpg|jpeg|png|gif|ico)$/', $image['type']) ) {$override = array('test_form' => false);// save the file, and store an array, containing its location in $file
		$file = wp_handle_upload( $image, $override );$plugin_options[$keys[$i]] = $file['url'];} else {// Not an image. 
		$options = get_option($this->option_name);$plugin_options[$keys[$i]] = $options[$logo];// Die and let the user know that they made a mistake.
		wp_die('No image was uploaded. Please try again');}}// Else, the user didn't upload a file.// Retain the image that's already on file.
		else {$options = get_option($this->option_name);$plugin_options[$keys[$i]] = $options[$keys[$i]];}$i++;}

		add_settings_error(__FILE__, 'settings_updated', __('Settings Updated',WPPM_LANG), 'updated' );
		return $plugin_options;
	}//function
	
	
	
	/**
	 * hooks the admin notices to the options page
	 *
	 * @package WPPM
	 * @since 3.3
	 *
	 * needed so the update message can be used
	 *
	 */
	function _admin_notices() {
		
    	settings_errors(__FILE__);
    	
    }//function
	
}//class
?>